<?php
require '../../vendor/PHPMailer/src/PHPMailer.php';
require '../../vendor/PHPMailer/src/SMTP.php';
require '../../vendor/PHPMailer/src/Exception.php';
require 'smtp_config.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

function sendMail($to, $template, $data = []) {
    $mail = new PHPMailer(true);

    try {
        // Extract the data array to variables
        extract($data);

        // Include the email template
        ob_start();
        include "../../templates/emails/$template.php";
        $template_content = ob_get_clean();

        // Replace shortcodes
        $shortcodes = [
            '[USER_NAME]' => $name ?? '',
            '[RESET_LINK]' => $reset_link ?? '',
            '[TICKET_ID]' => $ticket_id ?? '',
            '[PACKAGE_NAME]' => $package_name ?? '',
            '[NOTIFICATION_MESSAGE]' => $notification_message ?? '',
        ];

        foreach ($shortcodes as $shortcode => $value) {
            $template_content = str_replace($shortcode, $value, $template_content);
        }

        list($subject, $body) = explode("\n", trim($template_content), 2);

        // Server settings
        $mail->isSMTP();
        $mail->Host       = SMTP_HOST;
        $mail->SMTPAuth   = true;
        $mail->Username   = SMTP_USER;
        $mail->Password   = SMTP_PASS;
        $mail->SMTPSecure = SMTP_SECURE;
        $mail->Port       = SMTP_PORT;

        // Recipients
        $mail->setFrom(SMTP_FROM, SMTP_FROM_NAME);
        $mail->addAddress($to);

        // Content
        $mail->isHTML(true);
        $mail->Subject = trim($subject);
        $mail->Body    = trim($body);

        $mail->send();
        return true;
    } catch (Exception $e) {
        error_log("Message could not be sent. Mailer Error: {$mail->ErrorInfo}");
        return false;
    }
}
?>
