<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$pageTitle = "Packages";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');

// Fetch user's current subscription
$user_id = $_SESSION['user_id'];
$stmt = $conn->prepare("SELECT subscriptions.*, packages.website_limit FROM subscriptions 
                        JOIN packages ON subscriptions.package_id = packages.id 
                        WHERE subscriptions.user_id = ? AND subscriptions.status = 'Active'");
$stmt->execute([$user_id]);
$current_subscription = $stmt->fetch(PDO::FETCH_ASSOC);

// Fetch all packages from the database
$stmt = $conn->prepare("SELECT * FROM packages");
$stmt->execute();
$packages = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Fetch the number of websites user has already added
$stmt = $conn->prepare("SELECT COUNT(*) as website_count FROM cdn_websites WHERE user_id = ?");
$stmt->execute([$user_id]);
$website_count = $stmt->fetch(PDO::FETCH_ASSOC)['website_count'];
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">Packages</h1>
            <ul class="nav nav-tabs" id="myTab" role="tablist">
                <li class="nav-item">
                    <a class="nav-link active" id="monthly-tab" data-toggle="tab" href="#monthly" role="tab" aria-controls="monthly" aria-selected="true">Monthly</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" id="yearly-tab" data-toggle="tab" href="#yearly" role="tab" aria-controls="yearly" aria-selected="false">Yearly</a>
                </li>
            </ul>
            <div class="tab-content" id="myTabContent">
                <div class="tab-pane fade show active" id="monthly" role="tabpanel" aria-labelledby="monthly-tab">
                    <div class="row">
                        <?php foreach ($packages as $package): ?>
                            <?php if (strtolower($package['billing_cycle']) == 'monthly'): ?>
                                <?php
                                $is_current = $current_subscription && $current_subscription['package_id'] == $package['id'];
                                $can_downgrade = $package['website_limit'] >= $website_count || $package['website_limit'] == -1;
                                ?>
                                <div class="col-lg-4 mb-4">
                                    <div class="card shadow-sm package-card">
                                        <div class="card-header bg-primary text-white py-3">
                                            <h6 class="m-0 font-weight-bold"><?php echo htmlspecialchars($package['name']); ?></h6>
                                        </div>
                                        <div class="card-body">
                                            <h5 class="card-title">$<?php echo htmlspecialchars($package['monthly_price']); ?> <small class="text-muted">/ month</small></h5>
                                            <ul class="list-unstyled mt-3 mb-4">
                                                <?php foreach (explode("\n", $package['features']) as $feature): ?>
                                                    <li><i class="fas fa-check text-success"></i> <?php echo htmlspecialchars($feature); ?></li>
                                                <?php endforeach; ?>
                                            </ul>
                                            <?php if ($is_current): ?>
                                                <button class="btn btn-secondary btn-block" disabled>Current Package</button>
                                            <?php elseif (!$can_downgrade && $package['website_limit'] != -1): ?>
                                                <button class="btn btn-danger btn-block downgrade-btn" data-package-id="<?php echo $package['id']; ?>" data-package-limit="<?php echo $package['website_limit']; ?>">Downgrade</button>
                                            <?php else: ?>
                                                <a href="checkout.php?package_id=<?php echo htmlspecialchars($package['id']); ?>&billing_cycle=monthly" class="btn btn-primary btn-block">Select Package</a>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </div>
                </div>
                <div class="tab-pane fade" id="yearly" role="tabpanel" aria-labelledby="yearly-tab">
                    <div class="row">
                        <?php foreach ($packages as $package): ?>
                            <?php if (strtolower($package['billing_cycle']) == 'yearly'): ?>
                                <?php
                                $is_current = $current_subscription && $current_subscription['package_id'] == $package['id'];
                                $can_downgrade = $package['website_limit'] >= $website_count || $package['website_limit'] == -1;
                                ?>
                                <div class="col-lg-4 mb-4">
                                    <div class="card shadow-sm package-card">
                                        <div class="card-header bg-primary text-white py-3">
                                            <h6 class="m-0 font-weight-bold"><?php echo htmlspecialchars($package['name']); ?></h6>
                                        </div>
                                        <div class="card-body">
                                            <h5 class="card-title">$<?php echo htmlspecialchars($package['yearly_price']); ?> <small class="text-muted">/ year</small></h5>
                                            <ul class="list-unstyled mt-3 mb-4">
                                                <?php foreach (explode("\n", $package['features']) as $feature): ?>
                                                    <li><i class="fas fa-check text-success"></i> <?php echo htmlspecialchars($feature); ?></li>
                                                <?php endforeach; ?>
                                            </ul>
                                            <?php if ($is_current): ?>
                                                <button class="btn btn-secondary btn-block" disabled>Current Package</button>
                                            <?php elseif (!$can_downgrade && $package['website_limit'] != -1): ?>
                                                <button class="btn btn-danger btn-block downgrade-btn" data-package-id="<?php echo $package['id']; ?>" data-package-limit="<?php echo $package['website_limit']; ?>">Downgrade</button>
                                            <?php else: ?>
                                                <a href="checkout.php?package_id=<?php echo htmlspecialchars($package['id']); ?>&billing_cycle=yearly" class="btn btn-primary btn-block">Select Package</a>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<!-- Downgrade Modal -->
<div class="modal fade" id="downgradeModal" tabindex="-1" role="dialog" aria-labelledby="downgradeModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="downgradeModalLabel">Downgrade Notice</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                You currently have more websites than the limit of the selected package. Please remove some websites before proceeding with the downgrade.
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
            </div>
        </div>
    </div>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
<script>
    $('.downgrade-btn').click(function() {
        var packageLimit = $(this).data('package-limit');
        var websiteCount = <?php echo $website_count; ?>;

        if (websiteCount > packageLimit) {
            $('#downgradeModal').modal('show');
        } else {
            window.location.href = 'checkout.php?package_id=' + $(this).data('package-id');
        }
    });
</script>

<style>
.package-card {
    transition: transform 0.3s ease, box-shadow 0.3s ease;
}

.package-card:hover {
    transform: translateY(-5px);
    box-shadow: 0 6px 12px rgba(0, 0, 0, 0.1);
}

.package-card .card-header {
    background-color: #4e73df;
    color: white;
}

.package-card .card-title {
    font-size: 1.5rem;
}

.package-card .btn {
    transition: background-color 0.3s ease, color 0.3s ease;
}

.package-card .btn:hover {
    background-color: #224abe;
    color: white;
}
</style>
</body>
</html>
