<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

function getActivePaymentGateways($conn) {
    $stmt = $conn->prepare("SELECT * FROM payment_gateways WHERE status = 'Active'");
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $package_id = intval($_POST['package_id']);
    $billing_cycle = $_POST['billing_cycle'];
    $gateway_name = $_POST['gateway_name'];
    $user_id = $_SESSION['user_id'];

    // Fetch package details
    $stmt = $conn->prepare("SELECT * FROM packages WHERE id = ?");
    $stmt->execute([$package_id]);
    $package = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$package) {
        header("Location: packages.php");
        exit();
    }

    // Adjust price based on billing cycle
    $package_price = $billing_cycle == 'yearly' ? $package['yearly_price'] : $package['monthly_price'];

    // Prepare payment data
    $payment_data = [
        'user_id' => $user_id,
        'package_id' => $package_id,
        'gateway_name' => $gateway_name,
        'package_price' => $package_price,
        'package_name' => $package['name'],
        'package_billing_cycle' => $billing_cycle,
    ];

    // Store payment data in session
    $_SESSION['payment_data'] = $payment_data;

    // Redirect to the appropriate payment gateway
    if ($gateway_name == 'Stripe') {
        header("Location: stripe_checkout.php");
    } else if ($gateway_name == 'PayPal') {
        $stmt = $conn->prepare("SELECT * FROM payment_gateways WHERE name = 'PayPal' AND status = 'Active'");
        $stmt->execute();
        $credentials = $stmt->fetch(PDO::FETCH_ASSOC);
        $client_id = $credentials['api_key'];
        $client_secret = $credentials['api_secret'];
        $mode = $credentials['mode'];

        // Set PayPal API endpoint based on mode
        $paypal_url = $mode == 'Live' ? "https://api.paypal.com/v1/payments/payment" : "https://api.sandbox.paypal.com/v1/payments/payment";

        // Prepare PayPal payment request
        $payment_request = [
            'intent' => 'sale',
            'redirect_urls' => [
                'return_url' => 'https://' . $_SERVER['HTTP_HOST'] . '/pages/user/paypal_success.php',
                'cancel_url' => 'https://' . $_SERVER['HTTP_HOST'] . '/pages/user/paypal_cancel.php'
            ],
            'payer' => [
                'payment_method' => 'paypal'
            ],
            'transactions' => [
                [
                    'amount' => [
                        'total' => number_format($package_price, 2, '.', ''),
                        'currency' => 'USD'
                    ],
                    'description' => $package['name']
                ]
            ]
        ];

        // Execute PayPal payment request
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $paypal_url);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/json',
            'Authorization: Basic ' . base64_encode($client_id . ':' . $client_secret)
        ]);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($payment_request));
        $response = curl_exec($ch);
        curl_close($ch);

        $response_data = json_decode($response, true);

        // Check for errors
        if (isset($response_data['error'])) {
            die('Error: ' . $response_data['error_description']);
        }

        // Redirect user to PayPal payment page
        foreach ($response_data['links'] as $link) {
            if ($link['rel'] == 'approval_url') {
                header("Location: " . $link['href']);
                exit();
            }
        }
    }
    exit();
}
?>
