<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$user_id = $_SESSION['user_id'];

// Fetch user's current subscription
$stmt = $conn->prepare("
    SELECT 
        subscriptions.*, 
        packages.name AS package_name,
        packages.website_limit,
        packages.bandwidth_limit,
        CASE 
            WHEN subscriptions.billing_cycle = 'monthly' THEN packages.monthly_price 
            WHEN subscriptions.billing_cycle = 'yearly' THEN packages.yearly_price 
        END AS package_price 
    FROM subscriptions 
    JOIN packages ON subscriptions.package_id = packages.id 
    WHERE subscriptions.user_id = ? AND subscriptions.status = 'Active'
");
$stmt->execute([$user_id]);
$current_subscription = $stmt->fetch(PDO::FETCH_ASSOC);

$pageTitle = "Subscriptions";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');

// Define status colors
$status_color = [
    'Active' => 'text-success font-weight-bold',
    'Expired' => 'text-danger font-weight-bold',
    'Pending' => 'text-warning font-weight-bold',
];
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">Subscriptions</h1>
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Current Subscription</h6>
                </div>
                <div class="card-body">
                    <?php if ($current_subscription): ?>
                        <div class="card mb-4">
                            <div class="card-body">
                                <h5 class="card-title"><?php echo htmlspecialchars($current_subscription['package_name']); ?></h5>
                                <p class="card-text">Price: $<?php echo htmlspecialchars($current_subscription['package_price']); ?> / <?php echo htmlspecialchars($current_subscription['billing_cycle']); ?></p>
                                <p class="card-text">Status: <span class="<?php echo $status_color[$current_subscription['status']]; ?>"><?php echo htmlspecialchars($current_subscription['status']); ?></span></p>
                                <p class="card-text">Start Date: <?php echo htmlspecialchars($current_subscription['start_date']); ?></p>
                                <p class="card-text">End Date: <?php echo htmlspecialchars($current_subscription['end_date']); ?></p>
                                <p class="card-text">Website Limit: <?php echo $current_subscription['website_limit'] == -1 ? 'Unlimited' : htmlspecialchars($current_subscription['website_limit']); ?></p>
                                <p class="card-text">Bandwidth Limit: <?php echo htmlspecialchars($current_subscription['bandwidth_limit']); ?> GB</p>
                                <!-- Add other subscription details as needed -->
                            </div>
                        </div>
                    <?php else: ?>
                        <p>You do not have an active subscription.</p>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
